import { RouterView } from 'vue-router';

export default {
    path: '/item',
    name: 'Item',
    meta: {
        title: 'items',
        icon: 'vn:item',
    },
    component: RouterView,
    redirect: { name: 'ItemMain' },
    menus: {
        main: ['ItemList', 'WasteBreakdown'],
        card: ['ItemBasicData'],
    },
    children: [
        {
            path: '',
            name: 'ItemMain',
            component: () => import('src/pages/Item/ItemMain.vue'),
            redirect: { name: 'ItemList' },
            children: [
                {
                    path: 'list',
                    name: 'ItemList',
                    meta: {
                        title: 'list',
                        icon: 'view_list',
                    },
                    component: () => import('src/pages/Item/ItemList.vue'),
                },
                {
                    path: 'create',
                    name: 'ItemCreate',
                    meta: {
                        title: 'create',
                    },
                    component: () => import('src/pages/Item/ItemCreate.vue'),
                },
                {
                    path: 'waste-breakdown',
                    name: 'WasteBreakdown',
                    meta: {
                        title: 'wasteBreakdown',
                        icon: 'vn:claims',
                    },
                    beforeEnter: (to, from, next) => {
                        next({ name: 'ItemList' });
                        window.location.href =
                            'https://grafana.verdnatura.es/d/TTNXQAxVk';
                    },
                },
            ],
        },
        {
            name: 'ItemCard',
            path: ':id',
            component: () => import('src/pages/Item/Card/ItemCard.vue'),
            redirect: { name: 'ItemSummary' },
            children: [
                {
                    name: 'ItemSummary',
                    path: 'summary',
                    meta: {
                        title: 'summary',
                        icon: 'launch',
                    },
                    component: () => import('src/pages/Item/Card/ItemSummary.vue'),
                },
                {
                    path: 'diary',
                    name: 'ItemDiary',
                    meta: {
                        title: 'diary',
                        icon: 'vn:transaction',
                    },
                    component: () => import('src/pages/Item/Card/ItemDiary.vue'),
                },
                {
                    path: 'tags',
                    name: 'ItemTags',
                    meta: {
                        title: 'Tags',
                        icon: 'vn:tags',
                    },
                    component: () => import('src/pages/Item/Card/ItemTags.vue'),
                },
                {
                    path: 'basic-data',
                    name: 'ItemBasicData',
                    meta: {
                        title: 'basicData',
                        icon: 'vn:settings',
                    },
                    component: () => import('src/pages/Item/Card/ItemBasicData.vue'),
                },
            ],
        },
    ],
};
